"""Tests for Nexia Home."""

import json
import os
from os.path import dirname
import unittest
import pytest

from nexia.home import NexiaHome


def load_fixture(filename):
    """Load a fixture."""
    test_dir = dirname(__file__)

    path = os.path.join(test_dir, "fixtures", filename)
    with open(path) as fptr:
        return fptr.read()


class TestNexiaThermostat(unittest.TestCase):
    """Tests for nexia thermostat."""

    def test_update(self):
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_houses_123456.json"))
        nexia.update_from_json(devices_json)
        thermostat = nexia.get_thermostat_by_id(2059661)
        zone_ids = thermostat.get_zone_ids()
        self.assertEqual(zone_ids, [83261002, 83261005, 83261008, 83261011])
        nexia.update_from_json(devices_json)
        zone_ids = thermostat.get_zone_ids()
        self.assertEqual(zone_ids, [83261002, 83261005, 83261008, 83261011])
        nexia.update_from_json(devices_json)

    def test_idle_thermo(self):
        """Get methods for an idle thermostat."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_houses_123456.json"))
        nexia.update_from_json(devices_json)

        thermostat = nexia.get_thermostat_by_id(2059661)

        self.assertEqual(thermostat.get_model(), "XL1050")
        self.assertEqual(thermostat.get_firmware(), "5.9.1")
        self.assertEqual(thermostat.get_dev_build_number(), "1581321824")
        self.assertEqual(thermostat.get_device_id(), "000000")
        self.assertEqual(thermostat.get_type(), "XL1050")
        self.assertEqual(thermostat.get_name(), "Downstairs East Wing")
        self.assertEqual(thermostat.get_deadband(), 3)
        self.assertEqual(thermostat.get_setpoint_limits(), (55, 99))
        self.assertEqual(thermostat.get_variable_fan_speed_limits(), (0.35, 1.0))
        self.assertEqual(thermostat.get_unit(), "F")
        self.assertEqual(thermostat.get_humidity_setpoint_limits(), (0.35, 0.65))
        self.assertEqual(thermostat.get_fan_mode(), "Auto")
        self.assertEqual(thermostat.get_fan_modes(), ["Auto", "On", "Circulate"])
        self.assertEqual(thermostat.get_outdoor_temperature(), 88.0)
        self.assertEqual(thermostat.get_relative_humidity(), 0.36)
        self.assertEqual(thermostat.get_current_compressor_speed(), 0.0)
        self.assertEqual(thermostat.get_requested_compressor_speed(), 0.0)
        self.assertEqual(thermostat.get_fan_speed_setpoint(), 0.35)
        self.assertEqual(thermostat.get_dehumidify_setpoint(), 0.50)
        self.assertEqual(thermostat.has_dehumidify_support(), True)
        self.assertEqual(thermostat.has_dehumidify_support(), True)
        self.assertEqual(thermostat.has_emergency_heat(), False)
        self.assertEqual(thermostat.get_system_status(), "System Idle")
        self.assertEqual(thermostat.has_air_cleaner(), True)
        self.assertEqual(thermostat.get_air_cleaner_mode(), "auto")
        self.assertEqual(thermostat.is_blower_active(), False)

        zone_ids = thermostat.get_zone_ids()
        self.assertEqual(zone_ids, [83261002, 83261005, 83261008, 83261011])

    def test_idle_thermo_issue_33758(self):
        """Get methods for an idle thermostat."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_house_issue_33758.json"))
        nexia.update_from_json(devices_json)

        thermostat = nexia.get_thermostat_by_id(12345678)

        self.assertEqual(thermostat.get_model(), "XL1050")
        self.assertEqual(thermostat.get_firmware(), "5.9.1")
        self.assertEqual(thermostat.get_dev_build_number(), "1581321824")
        self.assertEqual(thermostat.get_device_id(), "xxxxxx")
        self.assertEqual(thermostat.get_type(), "XL1050")
        self.assertEqual(thermostat.get_name(), "Thermostat")
        self.assertEqual(thermostat.get_deadband(), 3)
        self.assertEqual(thermostat.get_setpoint_limits(), (55, 99))
        self.assertEqual(thermostat.get_variable_fan_speed_limits(), (0.35, 1.0))
        self.assertEqual(thermostat.get_unit(), "F")
        self.assertEqual(thermostat.get_humidity_setpoint_limits(), (0.35, 0.65))
        self.assertEqual(thermostat.get_fan_mode(), "Auto")
        self.assertEqual(thermostat.get_fan_modes(), ["Auto", "On", "Circulate"])
        self.assertEqual(thermostat.get_outdoor_temperature(), 55.0)
        self.assertEqual(thermostat.get_relative_humidity(), 0.43)
        self.assertEqual(thermostat.get_current_compressor_speed(), 0.0)
        self.assertEqual(thermostat.get_requested_compressor_speed(), 0.0)
        self.assertEqual(thermostat.get_fan_speed_setpoint(), 1)
        self.assertEqual(thermostat.get_dehumidify_setpoint(), 0.55)
        self.assertEqual(thermostat.has_dehumidify_support(), True)
        self.assertEqual(thermostat.has_humidify_support(), True)
        self.assertEqual(thermostat.has_emergency_heat(), True)
        self.assertEqual(thermostat.is_emergency_heat_active(), False)
        self.assertEqual(thermostat.get_system_status(), "System Idle")
        self.assertEqual(thermostat.has_air_cleaner(), True)
        self.assertEqual(thermostat.get_air_cleaner_mode(), "auto")
        self.assertEqual(thermostat.is_blower_active(), False)

        zone_ids = thermostat.get_zone_ids()
        self.assertEqual(zone_ids, [12345678])

    def test_idle_thermo_issue_33968_thermostat_1690380(self):
        """Get methods for an cooling thermostat."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_house_issue_33968.json"))
        nexia.update_from_json(devices_json)

        thermostat_ids = nexia.get_thermostat_ids()
        self.assertEqual(thermostat_ids, [1690380])

        thermostat = nexia.get_thermostat_by_id(1690380)

        zone_ids = thermostat.get_zone_ids()
        self.assertEqual(zone_ids, [83037337, 83037340, 83037343])

        self.assertEqual(thermostat.get_model(), "XL1050")
        self.assertEqual(thermostat.get_firmware(), "5.9.1")
        self.assertEqual(thermostat.get_dev_build_number(), "1581321824")
        self.assertEqual(thermostat.get_device_id(), "removed")
        self.assertEqual(thermostat.get_type(), "XL1050")
        self.assertEqual(thermostat.get_name(), "Thermostat")
        self.assertEqual(thermostat.get_deadband(), 3)
        self.assertEqual(thermostat.get_setpoint_limits(), (55, 99))
        self.assertEqual(thermostat.get_variable_fan_speed_limits(), (0.35, 1.0))
        self.assertEqual(thermostat.get_unit(), "F")
        self.assertEqual(thermostat.get_humidity_setpoint_limits(), (0.35, 0.65))
        self.assertEqual(thermostat.get_fan_mode(), "Auto")
        self.assertEqual(thermostat.get_fan_modes(), ["Auto", "On", "Circulate"])
        self.assertEqual(thermostat.get_outdoor_temperature(), 80.0)
        self.assertEqual(thermostat.get_relative_humidity(), 0.55)
        self.assertEqual(thermostat.get_current_compressor_speed(), 0.41)
        self.assertEqual(thermostat.get_requested_compressor_speed(), 0.41)
        self.assertEqual(thermostat.get_fan_speed_setpoint(), 0.5)
        self.assertEqual(thermostat.get_dehumidify_setpoint(), 0.55)
        self.assertEqual(thermostat.has_dehumidify_support(), True)
        self.assertEqual(thermostat.has_humidify_support(), False)
        self.assertEqual(thermostat.has_emergency_heat(), True)
        self.assertEqual(thermostat.is_emergency_heat_active(), False)
        self.assertEqual(thermostat.get_system_status(), "Cooling")
        self.assertEqual(thermostat.has_air_cleaner(), True)
        self.assertEqual(thermostat.get_air_cleaner_mode(), "auto")
        self.assertEqual(thermostat.is_blower_active(), True)

    def test_active_thermo(self):
        """Get methods for an active thermostat."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_houses_123456.json"))
        nexia.update_from_json(devices_json)

        thermostat = nexia.get_thermostat_by_id(2293892)

        self.assertEqual(thermostat.get_model(), "XL1050")
        self.assertEqual(thermostat.get_firmware(), "5.9.1")
        self.assertEqual(thermostat.get_dev_build_number(), "1581321824")
        self.assertEqual(thermostat.get_device_id(), "0281B02C")
        self.assertEqual(thermostat.get_type(), "XL1050")
        self.assertEqual(thermostat.get_name(), "Master Suite")
        self.assertEqual(thermostat.get_deadband(), 3)
        self.assertEqual(thermostat.get_setpoint_limits(), (55, 99))
        self.assertEqual(thermostat.get_variable_fan_speed_limits(), (0.35, 1.0))
        self.assertEqual(thermostat.get_unit(), "F")
        self.assertEqual(thermostat.get_humidity_setpoint_limits(), (0.35, 0.65))
        self.assertEqual(thermostat.get_fan_mode(), "Auto")
        self.assertEqual(thermostat.get_fan_modes(), ["Auto", "On", "Circulate"])
        self.assertEqual(thermostat.get_outdoor_temperature(), 87.0)
        self.assertEqual(thermostat.get_relative_humidity(), 0.52)
        self.assertEqual(thermostat.get_current_compressor_speed(), 0.69)
        self.assertEqual(thermostat.get_requested_compressor_speed(), 0.69)
        self.assertEqual(thermostat.get_fan_speed_setpoint(), 0.35)
        self.assertEqual(thermostat.get_dehumidify_setpoint(), 0.45)
        self.assertEqual(thermostat.has_dehumidify_support(), True)
        self.assertEqual(thermostat.has_humidify_support(), False)
        self.assertEqual(thermostat.has_emergency_heat(), False)
        self.assertEqual(thermostat.get_system_status(), "Cooling")
        self.assertEqual(thermostat.has_air_cleaner(), True)
        self.assertEqual(thermostat.get_air_cleaner_mode(), "auto")
        self.assertEqual(thermostat.is_blower_active(), True)

        zone_ids = thermostat.get_zone_ids()
        self.assertEqual(zone_ids, [83394133, 83394130, 83394136, 83394127, 83394139])

    @pytest.mark.skip(reason="not yet supported")
    def test_xl624(self):
        """Get methods for an xl624 thermostat."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_house_xl624.json"))
        nexia.update_from_json(devices_json)

        thermostat_ids = nexia.get_thermostat_ids()
        self.assertEqual(thermostat_ids, [2222222, 3333333])
        thermostat = nexia.get_thermostat_by_id(1111111)

        self.assertEqual(thermostat.get_model(), None)
        self.assertEqual(thermostat.get_firmware(), "2.8")
        self.assertEqual(thermostat.get_dev_build_number(), "0603340208")
        self.assertEqual(thermostat.get_device_id(), None)
        self.assertEqual(thermostat.get_type(), None)
        self.assertEqual(thermostat.get_name(), "Downstairs Hall")
        self.assertEqual(thermostat.get_deadband(), 3)
        self.assertEqual(thermostat.get_setpoint_limits(), (55, 99))
        self.assertEqual(thermostat.has_variable_fan_speed(), False)
        self.assertEqual(thermostat.get_unit(), "F")
        self.assertEqual(thermostat.get_humidity_setpoint_limits(), (0.35, 0.65))
        self.assertEqual(thermostat.get_fan_mode(), "Auto")
        self.assertEqual(thermostat.get_fan_modes(), ["Auto", "On", "Cycler"])
        self.assertEqual(thermostat.get_current_compressor_speed(), 0.0)
        self.assertEqual(thermostat.get_requested_compressor_speed(), 0.0)
        self.assertEqual(thermostat.has_dehumidify_support(), False)
        self.assertEqual(thermostat.has_humidify_support(), False)
        self.assertEqual(thermostat.has_emergency_heat(), False)
        self.assertEqual(thermostat.get_system_status(), "System Idle")
        self.assertEqual(thermostat.has_air_cleaner(), False)
        self.assertEqual(thermostat.is_blower_active(), False)

        zone_ids = thermostat.get_zone_ids()
        self.assertEqual(zone_ids, [12345678])

    def test_xl824_1(self):
        """Get methods for an xl824 thermostat."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_house_xl624.json"))
        nexia.update_from_json(devices_json)

        thermostat_ids = nexia.get_thermostat_ids()
        self.assertEqual(thermostat_ids, [2222222, 3333333])
        thermostat = nexia.get_thermostat_by_id(2222222)

        self.assertEqual(thermostat.get_model(), "XL824")
        self.assertEqual(thermostat.get_firmware(), "5.9.1")
        self.assertEqual(thermostat.get_dev_build_number(), "1581314625")
        self.assertEqual(thermostat.get_device_id(), "0167CA48")
        self.assertEqual(thermostat.get_type(), "XL824")
        self.assertEqual(thermostat.get_name(), "Family Room")
        self.assertEqual(thermostat.get_deadband(), 3)
        self.assertEqual(thermostat.get_setpoint_limits(), (55, 99))
        self.assertEqual(thermostat.has_variable_fan_speed(), True)
        self.assertEqual(thermostat.get_unit(), "F")
        self.assertEqual(thermostat.get_humidity_setpoint_limits(), (0.35, 0.65))
        self.assertEqual(thermostat.get_fan_mode(), "Circulate")
        self.assertEqual(thermostat.get_fan_modes(), ["Auto", "On", "Circulate"])
        self.assertEqual(thermostat.get_current_compressor_speed(), 0.0)
        self.assertEqual(thermostat.get_requested_compressor_speed(), 0.0)
        self.assertEqual(thermostat.has_dehumidify_support(), True)
        self.assertEqual(thermostat.has_humidify_support(), False)
        self.assertEqual(thermostat.has_emergency_heat(), False)
        self.assertEqual(thermostat.get_system_status(), "System Idle")
        self.assertEqual(thermostat.has_air_cleaner(), True)
        self.assertEqual(thermostat.is_blower_active(), False)

        zone_ids = thermostat.get_zone_ids()
        self.assertEqual(zone_ids, [88888888])

    def test_xl824_2(self):
        """Get methods for an xl824 thermostat."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_house_xl624.json"))
        nexia.update_from_json(devices_json)

        thermostat_ids = nexia.get_thermostat_ids()
        self.assertEqual(thermostat_ids, [2222222, 3333333])
        thermostat = nexia.get_thermostat_by_id(3333333)

        self.assertEqual(thermostat.get_model(), "XL824")
        self.assertEqual(thermostat.get_firmware(), "5.9.1")
        self.assertEqual(thermostat.get_dev_build_number(), "1581314625")
        self.assertEqual(thermostat.get_device_id(), "01573380")
        self.assertEqual(thermostat.get_type(), "XL824")
        self.assertEqual(thermostat.get_name(), "Upstairs")
        self.assertEqual(thermostat.get_deadband(), 3)
        self.assertEqual(thermostat.get_setpoint_limits(), (55, 99))
        self.assertEqual(thermostat.has_variable_fan_speed(), True)
        self.assertEqual(thermostat.get_unit(), "F")
        self.assertEqual(thermostat.get_humidity_setpoint_limits(), (0.35, 0.65))
        self.assertEqual(thermostat.get_fan_mode(), "Circulate")
        self.assertEqual(thermostat.get_fan_modes(), ["Auto", "On", "Circulate"])
        self.assertEqual(thermostat.get_current_compressor_speed(), 0.0)
        self.assertEqual(thermostat.get_requested_compressor_speed(), 0.0)
        self.assertEqual(thermostat.has_dehumidify_support(), True)
        self.assertEqual(thermostat.has_humidify_support(), False)
        self.assertEqual(thermostat.has_emergency_heat(), False)
        self.assertEqual(thermostat.get_system_status(), "System Idle")
        self.assertEqual(thermostat.has_air_cleaner(), True)
        self.assertEqual(thermostat.is_blower_active(), False)

        zone_ids = thermostat.get_zone_ids()
        self.assertEqual(zone_ids, [99999999])


class TestNexiaHome(unittest.TestCase):
    """Tests for nexia home."""

    def test_basic(self):
        """Basic tests for NexiaHome."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_houses_123456.json"))
        nexia.update_from_json(devices_json)

        self.assertEqual(nexia.get_name(), "Hidden")
        thermostat_ids = nexia.get_thermostat_ids()
        self.assertEqual(thermostat_ids, [2059661, 2059676, 2293892, 2059652])

    def test_basic_issue_33758(self):
        """Basic tests for NexiaHome."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_house_issue_33758.json"))
        nexia.update_from_json(devices_json)

        self.assertEqual(nexia.get_name(), "Hidden")
        thermostat_ids = nexia.get_thermostat_ids()
        self.assertEqual(thermostat_ids, [12345678])


class TestNexiaThermostatZone(unittest.TestCase):
    """Tests for nexia thermostat zone."""

    def test_zone_issue_33968_zone_83037337(self):
        """Tests for nexia thermostat zone that is cooling."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_house_issue_33968.json"))
        nexia.update_from_json(devices_json)

        thermostat = nexia.get_thermostat_by_id(1690380)
        zone = thermostat.get_zone_by_id(83037337)

        self.assertEqual(zone.thermostat, thermostat)

        self.assertEqual(zone.get_name(), "Family Room")
        self.assertEqual(zone.get_cooling_setpoint(), 77)
        self.assertEqual(zone.get_heating_setpoint(), 74)
        self.assertEqual(zone.get_current_mode(), "COOL")
        self.assertEqual(
            zone.get_requested_mode(), "COOL",
        )
        self.assertEqual(
            zone.get_presets(), ["None", "Home", "Away", "Sleep"],
        )
        self.assertEqual(
            zone.get_preset(), "None",
        )
        self.assertEqual(
            zone.get_status(), "Damper Closed",
        )
        self.assertEqual(
            zone.get_setpoint_status(), "Permanent Hold",
        )
        self.assertEqual(zone.is_calling(), False)
        self.assertEqual(zone.is_in_permanent_hold(), True)

    def test_zone_issue_33968_zone_83037340(self):
        """Tests for nexia thermostat zone that is cooling."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_house_issue_33968.json"))
        nexia.update_from_json(devices_json)

        thermostat = nexia.get_thermostat_by_id(1690380)
        zone = thermostat.get_zone_by_id(83037340)

        self.assertEqual(zone.thermostat, thermostat)

        self.assertEqual(zone.get_name(), "Office")
        self.assertEqual(zone.get_cooling_setpoint(), 77)
        self.assertEqual(zone.get_heating_setpoint(), 74)
        self.assertEqual(zone.get_current_mode(), "COOL")
        self.assertEqual(
            zone.get_requested_mode(), "COOL",
        )
        self.assertEqual(
            zone.get_presets(), ["None", "Home", "Away", "Sleep"],
        )
        self.assertEqual(
            zone.get_preset(), "None",
        )
        self.assertEqual(
            zone.get_status(), "Damper Open",
        )
        self.assertEqual(
            zone.get_setpoint_status(), "Permanent Hold",
        )
        self.assertEqual(zone.is_calling(), True)
        self.assertEqual(zone.is_in_permanent_hold(), True)

    def test_zone_issue_33968_zone_83037343(self):
        """Tests for nexia thermostat zone that is cooling."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_house_issue_33968.json"))
        nexia.update_from_json(devices_json)

        thermostat = nexia.get_thermostat_by_id(1690380)
        zone = thermostat.get_zone_by_id(83037343)

        self.assertEqual(zone.thermostat, thermostat)

        self.assertEqual(zone.get_name(), "Master")
        self.assertEqual(zone.get_cooling_setpoint(), 77)
        self.assertEqual(zone.get_heating_setpoint(), 68)
        self.assertEqual(zone.get_current_mode(), "COOL")
        self.assertEqual(
            zone.get_requested_mode(), "COOL",
        )
        self.assertEqual(
            zone.get_presets(), ["None", "Home", "Away", "Sleep"],
        )
        self.assertEqual(
            zone.get_preset(), "None",
        )
        self.assertEqual(
            zone.get_status(), "Damper Open",
        )
        self.assertEqual(
            zone.get_setpoint_status(), "Permanent Hold",
        )
        self.assertEqual(zone.is_calling(), True)
        self.assertEqual(zone.is_in_permanent_hold(), True)

    def test_zone_issue_33758(self):
        """Tests for nexia thermostat zone relieving air."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_house_issue_33758.json"))
        nexia.update_from_json(devices_json)

        thermostat = nexia.get_thermostat_by_id(12345678)
        zone = thermostat.get_zone_by_id(12345678)

        self.assertEqual(zone.thermostat, thermostat)

        self.assertEqual(zone.get_name(), "Thermostat NativeZone")
        self.assertEqual(zone.get_cooling_setpoint(), 73)
        self.assertEqual(zone.get_heating_setpoint(), 68)
        self.assertEqual(zone.get_current_mode(), "AUTO")
        self.assertEqual(
            zone.get_requested_mode(), "AUTO",
        )
        self.assertEqual(
            zone.get_presets(), ["None", "Home", "Away", "Sleep"],
        )
        self.assertEqual(
            zone.get_preset(), "None",
        )
        self.assertEqual(
            zone.get_status(), "Idle",
        )
        self.assertEqual(
            zone.get_setpoint_status(), "Run Schedule - None",
        )
        self.assertEqual(zone.is_calling(), False)
        self.assertEqual(zone.is_in_permanent_hold(), False)

    def test_zone_relieving_air(self):
        """Tests for nexia thermostat zone relieving air."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_houses_123456.json"))
        nexia.update_from_json(devices_json)

        thermostat = nexia.get_thermostat_by_id(2293892)
        zone = thermostat.get_zone_by_id(83394133)

        self.assertEqual(zone.thermostat, thermostat)

        self.assertEqual(zone.get_name(), "Bath Closet")
        self.assertEqual(zone.get_cooling_setpoint(), 79)
        self.assertEqual(zone.get_heating_setpoint(), 63)
        self.assertEqual(zone.get_current_mode(), "AUTO")
        self.assertEqual(
            zone.get_requested_mode(), "AUTO",
        )
        self.assertEqual(
            zone.get_presets(), ["None", "Home", "Away", "Sleep"],
        )
        self.assertEqual(
            zone.get_preset(), "None",
        )
        self.assertEqual(
            zone.get_status(), "Relieving Air",
        )
        self.assertEqual(
            zone.get_setpoint_status(), "Permanent Hold",
        )
        self.assertEqual(zone.is_calling(), True)
        self.assertEqual(zone.is_in_permanent_hold(), True)

    def test_zone_cooling_air(self):
        """Tests for nexia thermostat zone cooling."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_houses_123456.json"))
        nexia.update_from_json(devices_json)

        thermostat = nexia.get_thermostat_by_id(2293892)
        zone = thermostat.get_zone_by_id(83394130)

        self.assertEqual(zone.get_name(), "Master")
        self.assertEqual(zone.get_cooling_setpoint(), 71)
        self.assertEqual(zone.get_heating_setpoint(), 63)
        self.assertEqual(zone.get_current_mode(), "AUTO")
        self.assertEqual(
            zone.get_requested_mode(), "AUTO",
        )
        self.assertEqual(
            zone.get_presets(), ["None", "Home", "Away", "Sleep"],
        )
        self.assertEqual(
            zone.get_preset(), "None",
        )
        self.assertEqual(
            zone.get_status(), "Damper Open",
        )
        self.assertEqual(
            zone.get_setpoint_status(), "Permanent Hold",
        )
        self.assertEqual(zone.is_calling(), True)
        self.assertEqual(zone.is_in_permanent_hold(), True)

    def test_zone_idle(self):
        """Tests for nexia thermostat zone idle."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_houses_123456.json"))
        nexia.update_from_json(devices_json)

        thermostat = nexia.get_thermostat_by_id(2059661)
        zone = thermostat.get_zone_by_id(83261002)

        self.assertEqual(zone.get_name(), "Living East")
        self.assertEqual(zone.get_cooling_setpoint(), 79)
        self.assertEqual(zone.get_heating_setpoint(), 63)
        self.assertEqual(zone.get_current_mode(), "AUTO")
        self.assertEqual(
            zone.get_requested_mode(), "AUTO",
        )
        self.assertEqual(
            zone.get_presets(), ["None", "Home", "Away", "Sleep"],
        )
        self.assertEqual(
            zone.get_preset(), "None",
        )
        self.assertEqual(
            zone.get_status(), "Idle",
        )
        self.assertEqual(
            zone.get_setpoint_status(), "Permanent Hold",
        )
        self.assertEqual(zone.is_calling(), False)
        self.assertEqual(zone.is_in_permanent_hold(), True)

    def test_xl824_idle(self):
        """Tests for nexia xl824 zone idle."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_house_xl624.json"))
        nexia.update_from_json(devices_json)

        thermostat_ids = nexia.get_thermostat_ids()
        self.assertEqual(thermostat_ids, [2222222, 3333333])
        thermostat = nexia.get_thermostat_by_id(3333333)
        zone = thermostat.get_zone_by_id(99999999)

        self.assertEqual(zone.get_name(), "Upstairs NativeZone")
        self.assertEqual(zone.get_cooling_setpoint(), 74)
        self.assertEqual(zone.get_heating_setpoint(), 62)
        self.assertEqual(zone.get_current_mode(), "COOL")
        self.assertEqual(
            zone.get_requested_mode(), "COOL",
        )
        self.assertEqual(
            zone.get_presets(), ["None", "Home", "Away", "Sleep"],
        )
        self.assertEqual(
            zone.get_preset(), "None",
        )
        self.assertEqual(
            zone.get_status(), "Idle",
        )
        self.assertEqual(
            zone.get_setpoint_status(), "Permanent Hold",
        )
        self.assertEqual(zone.is_calling(), False)
        self.assertEqual(zone.is_in_permanent_hold(), True)


class TestNexiaAutomation(unittest.TestCase):
    def test_automations(self):
        """Get methods for an active thermostat."""
        nexia = NexiaHome(auto_login=False)
        devices_json = json.loads(load_fixture("mobile_houses_123456.json"))
        nexia.update_from_json(devices_json)

        automation_ids = nexia.get_automation_ids()
        self.assertEqual(
            automation_ids,
            [3467876, 3467870, 3452469, 3452472, 3454776, 3454774, 3486078, 3486091],
        )

        automation_one = nexia.get_automation_by_id(3467876)

        self.assertEqual(automation_one.name, "Away for 12 Hours")
        self.assertEqual(
            automation_one.description,
            "When IFTTT activates the automation Upstairs West Wing will "
            "permanently hold the heat to 62.0 and cool to 83.0 AND "
            "Downstairs East Wing will permanently hold the heat to 62.0 "
            "and cool to 83.0 AND Downstairs West Wing will permanently "
            "hold the heat to 62.0 and cool to 83.0 AND Activate the mode "
            "named 'Away 12' AND Master Suite will permanently hold the "
            "heat to 62.0 and cool to 83.0",
        )
        self.assertEqual(automation_one.enabled, True)
        self.assertEqual(automation_one.automation_id, 3467876)



"""Nexia Themostat."""

import logging

from .const import (
    AIR_CLEANER_MODES,
    HUMIDITY_MAX,
    HUMIDITY_MIN,
    MOBILE_URL,
    SYSTEM_STATUS_IDLE,
    SYSTEM_STATUS_WAIT,
)
from .util import find_dict_with_keyvalue_in_json, is_number
from .zone import NexiaThermostatZone

_LOGGER = logging.getLogger(__name__)


class NexiaThermostat:
    """A nexia Thermostat.

    Represents a nexia thermostat.
    """

    API_MOBILE_THERMOSTAT_URL = (
        MOBILE_URL + "/xxl_thermostats/{thermostat_id}/{end_point}"
    )

    def __init__(self, nexia_home, thermostat_json):
        """Init nexia Thermostat."""
        self._nexia_home = nexia_home
        self.thermostat_id = thermostat_json["id"]
        self._thermostat_json = thermostat_json
        self.zones = []
        if self.has_zones():
            for zone in thermostat_json["zones"]:
                self.zones.append(NexiaThermostatZone(nexia_home, self, zone))

    def _get_thermostat_advanced_info_label(self, label):
        """
        Lookup advanced_info in the thermostat features and find the value of the
        requested label.
        """
        advanced_info = self._get_thermostat_features_key("advanced_info")

        try:
            return find_dict_with_keyvalue_in_json(
                advanced_info["items"], "label", label
            )["value"]
        except KeyError:
            return None

    def get_model(self):
        """
        Returns the thermostat model
        :return: string
        """
        return self._get_thermostat_advanced_info_label("Model")

    def get_firmware(self):
        """
        Returns the thermostat firmware version
        :return: string
        """
        return self._get_thermostat_advanced_info_label(
            "Firmware Version"
        ) or self._get_thermostat_advanced_info_label("Main Firmware Version")

    def get_dev_build_number(self):
        """
        Returns the thermostat development build number.
        :return: string
        """
        return self._get_thermostat_advanced_info_label(
            "Firmware Build Number"
        ) or self._get_thermostat_advanced_info_label("Version")

    def get_device_id(self):
        """
        Returns the device id
        :return: string
        """
        return self._get_thermostat_advanced_info_label("AUID")

    def get_type(self):
        """
        Returns the thermostat type, such as TraneXl1050
        :return: str
        """
        return self.get_model()

    def get_name(self):
        """
        Returns the name of the thermostat. This is not the zone name.
        :return: str
        """
        return self._get_thermostat_key("name")

    ########################################################################
    # Supported Features

    def has_outdoor_temperature(self):
        """
        Capability indication of whether the thermostat has an outdoor
        temperature sensor
        :return: bool
        """
        return self._get_thermostat_key_or_none("has_outdoor_temperature")

    def has_relative_humidity(self):
        """
        Capability indication of whether the thermostat has an relative
        humidity sensor
        :return: bool
        """
        return bool(self._get_thermostat_key_or_none("indoor_humidity"))

    def has_variable_speed_compressor(self):
        """
        Capability indication of whether the thermostat has a variable speed
        compressor
        :return: bool
        """
        # This only shows up if its running on mobile
        return True

    def has_emergency_heat(self):
        """
        Capability indication of whether the thermostat has emergency/aux heat.
        :return: bool
        """
        return bool(self.get_thermostat_settings_key_or_none("emergency_heat"))

    def has_variable_fan_speed(self):
        """
        Capability indication of whether the thermostat has a variable speed
        blower
        :return: bool
        """
        return bool(self.get_thermostat_settings_key_or_none("fan_speed"))

    def has_zones(self):
        """
        Indication of whether zoning is enabled or not on the thermostat.
        :return: bool
        """
        return bool(self._get_thermostat_key_or_none("zones"))

    def has_dehumidify_support(self):
        """
        Indiciation of whether dehumidifying support is available.
        :return: bool
        """
        return bool(self.get_thermostat_settings_key_or_none("dehumidify"))

    def has_humidify_support(self):
        """
        Indiciation of whether humidifying support is available.
        :return: bool
        """
        return bool(self.get_thermostat_settings_key_or_none("humidify"))

    ########################################################################
    # System Attributes

    def get_deadband(self):
        """
        Returns the deadband of the thermostat. This is the minimum number of
        degrees between the heat and cool setpoints in the number of degrees in
        the temperature unit selected by the
        thermostat.
        :return: int
        """
        return self._get_thermostat_features_key("thermostat")["setpoint_delta"]

    def get_setpoint_limits(self):
        """
        Returns a tuple of the minimum and maximum temperature that can be set
        on any zone. This is in the temperature unit selected by the
        thermostat.
        :return: (int, int)
        """
        return (
            self._get_thermostat_features_key("thermostat")["setpoint_heat_min"],
            self._get_thermostat_features_key("thermostat")["setpoint_cool_max"],
        )

    def get_variable_fan_speed_limits(self):
        """
        Returns the variable fan speed setpoint limits of the thermostat.
        :return: (float, float)
        """
        if self.has_variable_fan_speed():
            possible_values = self.get_thermostat_settings_key("fan_speed")["values"]
            return (possible_values[0], possible_values[-1])
        raise AttributeError("This thermostat does not support fan speeds")

    def get_unit(self):
        """
        Returns the temperature unit used by this system, either C or F.
        :return: str
        """
        return self._get_thermostat_features_key("thermostat")["scale"].upper()

    def get_humidity_setpoint_limits(self):
        """
        Returns the humidity setpoint limits of the thermostat.

        This is a hard-set limit in this code that I believe is universal to
        all TraneXl thermostats.
        but kept for consistency)
        :return: (float, float)
        """
        return HUMIDITY_MIN, HUMIDITY_MAX

    ########################################################################
    # System Universal Boolean Get Methods

    def is_blower_active(self):
        """
        Returns True if the blower is active
        :return: bool
        """
        system_status = self.get_system_status()
        return system_status not in (SYSTEM_STATUS_WAIT, SYSTEM_STATUS_IDLE)

    def is_emergency_heat_active(self):
        """
        Returns True if the emergency/aux heat is active
        :return: bool
        """
        if self.has_emergency_heat():
            return self.get_thermostat_settings_key("emergency_heat")["current_value"]
        raise Exception("This system does not support emergency heat")

    ########################################################################
    # System Universal Get Methods

    def get_fan_modes(self):
        """
        Returns the list of fan modes the device supports

        :return:
        """
        options = self.get_thermostat_settings_key("fan_mode")["options"]
        return [opt["label"] for opt in options]

    def get_fan_mode(self):
        """
        Returns the current fan mode. See get_fan_modes for the available options.
        :return: str
        """
        fan_mode = self.get_thermostat_settings_key("fan_mode")
        current_value = fan_mode["current_value"]
        options = fan_mode["options"]
        for opt in options:
            if opt["value"] == current_value:
                return opt["label"]
        return None

    def get_outdoor_temperature(self):
        """
        Returns the outdoor temperature.
        :return: float - the temperature, returns nan if invalid
        """
        if self.has_outdoor_temperature():
            outdoor_temp = self._get_thermostat_key("outdoor_temperature")
            if is_number(outdoor_temp):
                return float(outdoor_temp)
            return float("Nan")
        raise Exception("This system does not have an outdoor temperature sensor")

    def get_relative_humidity(self):
        """
        Returns the indoor relative humidity as a percent (0-1)
        :return: float
        """
        if self.has_relative_humidity():
            return float(self._get_thermostat_key("indoor_humidity")) / 100
        raise Exception("This system does not have a relative humidity sensor.")

    def get_current_compressor_speed(self):
        """
        Returns the variable compressor speed, if supported, as a percent (0-1)
        :return: float
        """
        thermostat_compressor_speed = self._get_thermostat_features_key_or_none(
            "thermostat_compressor_speed"
        )
        if thermostat_compressor_speed is None:
            return 0
        return float(thermostat_compressor_speed["compressor_speed"])

    def get_requested_compressor_speed(self):
        """
        Returns the variable compressor's requested speed, if supported, as a
        percent (0-1)
        :return: float
        """
        # mobile api does not have a requested speed
        return self.get_current_compressor_speed()

    def get_fan_speed_setpoint(self):
        """
        Returns the current variable fan speed setpoint from 0-1.
        :return: float
        """
        if self.has_variable_fan_speed():
            return self.get_thermostat_settings_key("fan_speed")["current_value"]
        raise AttributeError("This system does not have variable fan speed.")

    def get_dehumidify_setpoint(self):
        """
        Returns the dehumidify setpoint from 0-1
        :return: float
        """
        if self.has_dehumidify_support():
            return self.get_thermostat_settings_key("dehumidify")["current_value"]

        raise AttributeError("This system does not support " "dehumidification")

    def get_humidify_setpoint(self):
        """
        Returns the dehumidify setpoint from 0-1
        :return: float
        """
        if self.has_humidify_support():
            return self.get_thermostat_settings_key("humidify")["current_value"]

        raise AttributeError("This system does not support humidification")

    def get_system_status(self):
        """
        Returns the system status such as "System Idle" or "Cooling"
        :return: str
        """
        return self._get_thermostat_key_or_none(
            "system_status"
        ) or self._get_thermostat_key("operating_state")

    def has_air_cleaner(self):
        """
        Returns if the system has an air cleaner.
        :return: bool
        """
        return bool(self.get_thermostat_settings_key_or_none("air_cleaner_mode"))

    def get_air_cleaner_mode(self):
        """
        Returns the system's air cleaner mode
        :return: str
        """
        return self.get_thermostat_settings_key("air_cleaner_mode")["current_value"]

    ########################################################################
    # System Universal Set Methods

    def set_fan_mode(self, fan_mode: str):
        """
        Sets the fan mode.
        :param fan_mode: string that must be in self.get_fan_modes()
        :return: None
        """
        fan_mode_data = self.get_thermostat_settings_key("fan_mode")
        options = fan_mode_data["options"]
        for opt in options:
            if opt["label"] == fan_mode:
                fan_mode = opt["value"]
                break

        self._post_and_update_thermostat_json("fan_mode", {"value": fan_mode})

    def set_fan_setpoint(self, fan_setpoint: float):
        """
        Sets the fan's setpoint speed as a percent in range. You can see the
        limits by calling Nexia.get_variable_fan_speed_limits()
        :param fan_setpoint: float
        :return: None
        """

        # This call will get the limits, as well as check if this system has
        # a variable speed fan
        min_speed, max_speed = self.get_variable_fan_speed_limits()

        if min_speed <= fan_setpoint <= max_speed:
            self._post_and_update_thermostat_json("fan_speed", {"value": fan_setpoint})
        else:
            raise ValueError(
                f"The fan setpoint, {fan_setpoint} is not "
                f"between {min_speed} and {max_speed}."
            )

    def set_air_cleaner(self, air_cleaner_mode: str):
        """
        Sets the air cleaner mode.
        :param air_cleaner_mode: string that must be in
        AIR_CLEANER_MODES
        :return: None
        """
        air_cleaner_mode = air_cleaner_mode.lower()
        if air_cleaner_mode in AIR_CLEANER_MODES:
            if air_cleaner_mode != self.get_air_cleaner_mode():
                self._post_and_update_thermostat_json(
                    "air_cleaner_mode", {"value": air_cleaner_mode}
                )
        else:
            raise KeyError("Invalid air cleaner mode specified")

    def set_follow_schedule(self, follow_schedule):
        """
        Enables or disables scheduled operation
        :param follow_schedule: bool - True for follow schedule, False for hold
        current setpoints
        :return: None
        """
        self._post_and_update_thermostat_json(
            "scheduling_enabled", {"value": "true" if follow_schedule else "false"}
        )

    def set_emergency_heat(self, emergency_heat_on):
        """
        Enables or disables emergency / auxiliary heat.
        :param emergency_heat_on: bool - True for enabled, False for Disabled
        :return: None
        """
        if self.has_emergency_heat():
            self._post_and_update_thermostat_json(
                "emergency_heat", {"value": bool(emergency_heat_on)}
            )
        else:
            raise Exception("This thermostat does not support emergency heat.")

    def set_humidity_setpoints(self, **kwargs):
        """

        :param dehumidify_setpoint: float - The dehumidify_setpoint, 0-1, disable: None
        :param humidify_setpoint: float - The humidify setpoint, 0-1, disable: None
        :return:
        """

        dehumidify_setpoint = kwargs.get("dehumidify_setpoint", None)
        humidify_setpoint = kwargs.get("humidify_setpoint", None)

        if dehumidify_setpoint is None and humidify_setpoint is None:
            # Do nothing
            return

        if self.has_relative_humidity():
            (min_humidity, max_humidity) = self.get_humidity_setpoint_limits()
            if self.has_humidify_support():
                humidify_supported = True
                if humidify_setpoint is None:
                    humidify_setpoint = self.get_humidify_setpoint()
            else:
                if humidify_setpoint is not None:
                    raise SystemError("This thermostat does not support humidifying.")
                humidify_supported = False
                humidify_setpoint = 0

            if self.has_dehumidify_support():
                dehumidify_supported = True
                if dehumidify_setpoint is None:
                    dehumidify_setpoint = self.get_dehumidify_setpoint()
            else:
                if dehumidify_setpoint is not None:
                    raise SystemError("This thermostat does not support dehumidifying.")
                dehumidify_supported = False
                dehumidify_setpoint = 0

            # Clean up input
            dehumidify_setpoint = round(0.05 * round(dehumidify_setpoint / 0.05), 2)
            humidify_setpoint = round(0.05 * round(humidify_setpoint / 0.05), 2)

            # Check inputs
            if (dehumidify_supported and humidify_supported) and not (
                min_humidity <= humidify_setpoint <= dehumidify_setpoint <= max_humidity
            ):
                raise ValueError(
                    f"Setpoints must be between ({min_humidity} -"
                    f" {max_humidity}) and humdiify_setpoint must"
                    f" be <= dehumidify_setpoint"
                )
            if (dehumidify_supported) and not (
                min_humidity <= dehumidify_setpoint <= max_humidity
            ):
                raise ValueError(
                    f"dehumidify_setpoint must be between "
                    f"({min_humidity} - {max_humidity})"
                )
            if (humidify_supported) and not (
                min_humidity <= humidify_setpoint <= max_humidity
            ):
                raise ValueError(
                    f"humidify_setpoint must be between "
                    f"({min_humidity} - {max_humidity})"
                )

            self._post_and_update_thermostat_json(
                "dehumidify", {"value": dehumidify_setpoint}
            )
        else:
            raise Exception(
                "Setting target humidity is not supported on this thermostat."
            )

    def set_dehumidify_setpoint(self, dehumidify_setpoint):
        """
        Sets the overall system's dehumidify setpoint as a percent (0-1).

        The system must support
        :param dehumidify_setpoint: float
        :return: None
        """
        self.set_humidity_setpoints(dehumidify_setpoint=dehumidify_setpoint)

    def set_humidify_setpoint(self, humidify_setpoint):
        """
        Sets the overall system's humidify setpoint as a percent (0-1).

        The system must support
        :param humidify_setpoint: float
        :return: None
        """
        self.set_humidity_setpoints(humidify_setpoint=humidify_setpoint)

    ########################################################################
    # Zone Get Methods

    def get_zone_ids(self):
        """
        Returns a list of available zone IDs with a starting index of 0.
        :return: list(int)
        """
        # The zones are in a list, so there are no keys to pull out. I have to
        # create a new list of IDs.
        zone_list = []
        for zone in self.zones:
            zone_list.append(zone.zone_id)

        return zone_list

    def get_zone_by_id(self, zone_id):
        """Get a zone by its nexia id."""
        for zone in self.zones:
            if zone.zone_id == zone_id:
                return zone
        raise KeyError

    def _get_thermostat_deep_key(self, area, area_primary_key, key):
        """
        Returns the thermostat value from deep inside the thermostat's
        JSON.
        :param area: The area of the json to look i.e. "settings", "features", etc
        :param area_primary_key: The name of the primary key such as "name" or "key"
        :param key: str
        :return: value
        """
        data = find_dict_with_keyvalue_in_json(
            self._thermostat_json[area], area_primary_key, key
        )

        if not data:
            raise KeyError(f'Key "{key}" not in the thermostat JSON!')
        return data

    def _get_thermostat_features_key_or_none(self, key):
        """
        Returns the thermostat value from the provided key in the thermostat's
        JSON.
        :param key: str
        :return: value
        """
        try:
            return self._get_thermostat_features_key(key)
        except KeyError:
            return None

    def _get_thermostat_features_key(self, key):
        """
        Returns the thermostat value from the provided key in the thermostat's
        JSON.
        :param key: str
        :return: value
        """
        return self._get_thermostat_deep_key("features", "name", key)

    def _get_thermostat_key_or_none(self, key):
        """
        Returns the thermostat value from the provided key in the thermostat's
        JSON.
        :param key: str
        :return: value
        """
        try:
            return self._get_thermostat_key(key)
        except KeyError:
            return None

    def _get_thermostat_key(self, key):
        """
        Returns the thermostat value from the provided key in the thermostat's
        JSON.
        :param key: str
        :return: value
        """
        thermostat = self._thermostat_json
        if key in thermostat:
            return thermostat[key]

        raise KeyError(f'Key "{key}" not in the thermostat JSON!')

    def get_thermostat_settings_key_or_none(self, key):
        """
        Returns the thermostat value from the provided key in the thermostat's
        JSON.
        :param key: str
        :return: value
        """
        try:
            return self.get_thermostat_settings_key(key)
        except KeyError:
            return None

    def get_thermostat_settings_key(self, key):
        """
        Returns the thermostat value from the provided key in the thermostat's
        JSON.
        :param key: str
        :return: value
        """
        return self._get_thermostat_deep_key("settings", "type", key)

    def _get_zone_json(self, zone_id=0):
        """
        Returns the thermostat zone's JSON
        :param zone_id: The index of the zone, defaults to 0.
        :return: dict(thermostat_json['zones'][zone_id])
        """
        thermostat = self._thermostat_json
        if not thermostat:
            return None

        zone = find_dict_with_keyvalue_in_json(thermostat["zones"], "id", zone_id)

        if not zone:
            raise IndexError(
                f"The zone_id ({zone_id}) does not exist in the thermostat zones."
            )
        return zone

    def _post_and_update_thermostat_json(self, end_point, payload):
        url = self.API_MOBILE_THERMOSTAT_URL.format(
            end_point=end_point, thermostat_id=self._thermostat_json["id"]
        )
        response = self._nexia_home.post_url(url, payload)
        self.update_thermostat_json(response.json()["result"])

    def update_thermostat_json(self, thermostat_json):
        """Update with new json from the api"""
        if self._thermostat_json is None:
            return

        _LOGGER.debug(
            "Updated thermostat_id:%s with new data from post", self.thermostat_id,
        )
        self._thermostat_json.update(thermostat_json)

        zone_updates_by_id = {}
        for zone_json in thermostat_json["zones"]:
            zone_updates_by_id[zone_json["id"]] = zone_json

        for zone in self.zones:
            if zone.zone_id in zone_updates_by_id:
                zone.update_zone_json(zone_updates_by_id[zone.zone_id])



"""Utils."""

import json
from json import JSONDecodeError
import uuid


def is_number(string):
    """String is a number."""
    try:
        float(string)
        return True
    except ValueError:
        return False


def find_dict_with_keyvalue_in_json(json_dict, key_in_subdict, value_to_find):
    """
    Searches a json_dict for the key key_in_subdict that matches value_to_find
    :param json_dict: dict
    :param key_in_subdict: str - the name of the key in the subdict to find
    :param value_to_find: str - the value of the key in the subdict to find
    :return: The subdict to find
    """
    for data_group in json_dict:
        if data_group.get(key_in_subdict) == value_to_find:
            return data_group

    raise KeyError


def load_or_create_uuid(filename):
    """Load or create a uuid for the device."""
    try:
        with open(filename) as fptr:
            jsonf = json.loads(fptr.read())
            return uuid.UUID(jsonf["nexia_uuid"], version=4)
    except (JSONDecodeError, FileNotFoundError):
        return _create_uuid(filename)
    except (ValueError, AttributeError):
        return None


def _create_uuid(filename):
    """Create a uuid for the device."""
    with open(filename, "w") as fptr:
        new_uuid = uuid.uuid4()
        fptr.write(json.dumps({"nexia_uuid": str(new_uuid)}))
        return new_uuid



"""Top-level package for Nexia."""

__version__ = "0.1.0"

ROOT_URL = "https://www.mynexia.com"
MOBILE_URL = f"{ROOT_URL}/mobile"

DEFAULT_DEVICE_NAME = "Home Automation"

PUT_UPDATE_DELAY = 0.5

HOLD_PERMANENT = "permanent_hold"
HOLD_RESUME_SCHEDULE = "run_schedule"

OPERATION_MODE_AUTO = "AUTO"
OPERATION_MODE_COOL = "COOL"
OPERATION_MODE_HEAT = "HEAT"
OPERATION_MODE_OFF = "OFF"
OPERATION_MODES = [
    OPERATION_MODE_AUTO,
    OPERATION_MODE_COOL,
    OPERATION_MODE_HEAT,
    OPERATION_MODE_OFF,
]

# The order of these is important as it maps to preset#
PRESET_MODE_HOME = "Home"
PRESET_MODE_AWAY = "Away"
PRESET_MODE_SLEEP = "Sleep"
PRESET_MODE_NONE = "None"

SYSTEM_STATUS_COOL = "Cooling"
SYSTEM_STATUS_HEAT = "Heating"
SYSTEM_STATUS_WAIT = "Waiting..."
SYSTEM_STATUS_IDLE = "System Idle"

AIR_CLEANER_MODE_AUTO = "auto"
AIR_CLEANER_MODE_QUICK = "quick"
AIR_CLEANER_MODE_ALLERGY = "allergy"
AIR_CLEANER_MODES = [
    AIR_CLEANER_MODE_AUTO,
    AIR_CLEANER_MODE_QUICK,
    AIR_CLEANER_MODE_ALLERGY,
]

HUMIDITY_MIN = 0.35
HUMIDITY_MAX = 0.65

APP_VERSION = "5.9.0"

UNIT_CELSIUS = "C"
UNIT_FAHRENHEIT = "F"

DAMPER_CLOSED = "Damper Closed"
DAMPER_OPEN = "Damper Open"

ZONE_IDLE = "Idle"

ALL_IDS = "all"
